### Name: dc.fit
### Title: Iterative model fitting with data cloning
### Aliases: dc.fit
### Keywords: models htest

### ** Examples

## Not run: 
##D ## simulation for Poisson GLMM
##D set.seed(1234)
##D n <- 20
##D beta <- c(2, -1)
##D sigma <- 0.1
##D alpha <- rnorm(n, 0, sigma)
##D x <- runif(n)
##D X <- model.matrix(~x)
##D linpred <- X %*% beta + alpha
##D Y <- rpois(n, exp(linpred))
##D ## JAGS model as a function
##D jfun1 <- function() {
##D     for (i in 1:n) {
##D         Y[i] ~ dpois(lambda[i])
##D         log(lambda[i]) <- alpha[i] + inprod(X[i,], beta[1,])
##D         alpha[i] ~ dnorm(0, 1/sigma^2)
##D     }
##D     for (j in 1:np) {
##D         beta[1,j] ~ dnorm(0, 0.001)
##D     }
##D     sigma ~ dlnorm(0, 0.001)
##D }
##D ## data
##D jdata <- list(n = n, Y = Y, X = X, np = NCOL(X))
##D ## number of clones to be used, etc.
##D ## iteartive fitting
##D jmod <- dc.fit(jdata, c("beta", "sigma"), jfun1, 
##D     n.clones = 1:5, multiply = "n", unchanged = "np")
##D ## summary with DC SE and R hat
##D summary(jmod)
##D dct <- dctable(jmod)
##D plot(dct)
##D ## How to use estimates to make priors more informative?
##D glmm.model.up <- function() {
##D     for (i in 1:n) {
##D         Y[i] ~ dpois(lambda[i])
##D         log(lambda[i]) <- alpha[i] + inprod(X[i,], beta[1,])
##D         alpha[i] ~ dnorm(0, 1/sigma^2)
##D     }
##D     for (j in 1:p) {
##D         beta[1,j] ~ dnorm(priors[j,1], priors[j,2])
##D     }
##D     sigma ~ dgamma(priors[(p+1),2], priors[(p+1),1])
##D }
##D ## function for updating, x is an MCMC object
##D upfun <- function(x) {
##D     if (missing(x)) {
##D         p <- ncol(X)
##D         return(cbind(c(rep(0, p), 0.001), rep(0.001, p+1)))
##D     } else {
##D         par <- coef(x)
##D         return(cbind(par, rep(0.01, length(par))))
##D     }
##D }
##D updat <- list(n = n, Y = Y, X = X, p = ncol(X), priors = upfun())
##D dcmod <- dc.fit(updat, c("beta", "sigma"), glmm.model.up,
##D     n.clones = 1:5, multiply = "n", unchanged = "p",
##D     update = "priors", updatefun = upfun)
##D summary(dcmod)
##D ## time series example
##D ## data and model taken from Ponciano et al. 2009
##D ## Ecology 90, 356-362.
##D paurelia <- c(17,29,39,63,185,258,267,392,510,570,650,560,575,650,550,480,520,500)
##D dat <- list(ncl=1, n=length(paurelia), Y=as.ts(paurelia))
##D beverton.holt <- function() {
##D     for (k in 1:ncl) {
##D         for(i in 2:(n+1)){
##D             ## observations
##D             Y[(i-1), k] ~ dpois(exp(X[i, k]))
##D             ## state
##D             X[i, k] ~ dnorm(mu[i, k], 1 / sigma^2)
##D             mu[i, k] <- X[(i-1), k] + log(lambda) - log(1 + beta * exp(X[(i-1), k]))
##D         }
##D         ## state at t0
##D         X[1, k] ~ dnorm(mu0, 1 / sigma^2)
##D     }
##D     # Priors on model parameters
##D     beta ~ dlnorm(-1, 1)
##D     sigma ~ dlnorm(0, 1)
##D     tmp ~ dlnorm(0, 1)
##D     lambda <- tmp + 1
##D     mu0 <- log(2)  + log(lambda) - log(1 + beta * 2)
##D }
##D mod <- dc.fit(dat, c("lambda","beta","sigma"), beverton.holt,
##D     n.clones=c(2, 5, 10), multiply="ncl", unchanged="n")
##D ## compare with results from the paper:
##D ##   beta   = 0.00235
##D ##   lambda = 2.274
##D ##   sigma  = 0.1274
##D summary(mod)
## End(Not run)



