### Encoding: UTF-8

### Name: jags.fit
### Title: Fit JAGS/BUGS models with cloned data
### Aliases: jags.fit bugs.fit as.mcmc.list.bugs
### Keywords: models

### ** Examples

## Not run: 
##D ## simple regression example from the JAGS manual
##D jfun <- function() {
##D     for (i in 1:N) {
##D         Y[i] ~ dnorm(mu[i], tau)
##D         mu[i] <- alpha + beta * (x[i] - x.bar)
##D     }
##D     x.bar <- mean(x[])
##D     alpha ~ dnorm(0.0, 1.0E-4)
##D     beta ~ dnorm(0.0, 1.0E-4)
##D     sigma <- 1.0/sqrt(tau)
##D     tau ~ dgamma(1.0E-3, 1.0E-3)
##D }
##D ## data generation
##D set.seed(1234)
##D N <- 100
##D alpha <- 1
##D beta <- -1
##D sigma <- 0.5
##D x <- runif(N)
##D linpred <- model.matrix(~x) %*% c(alpha, beta)
##D Y <- rnorm(N, mean = linpred, sd = sigma)
##D ## list of data for the model
##D jdata <- list(N = N, Y = Y, x = x)
##D ## what to monitor
##D jpara <- c("alpha", "beta", "sigma")
##D #### fit the model with JAGS
##D regmod <- jags.fit(jdata, jpara, jfun, n.chains = 3)
##D ## model summary
##D summary(regmod)
##D ## data cloning
##D dcdata <- dclone(jdata, 5, multiply = "N")
##D dcmod <- jags.fit(dcdata, jpara, jfun, n.chains = 3)
##D summary(dcmod)
##D #### fitting with WinBUGS, bugs example
##D data(schools)
##D dat <- list(J = nrow(schools), y = schools$estimate, sigma.y = schools$sd)
##D bugs.model <- function(){
##D        for (j in 1:J){
##D          y[j] ~ dnorm (theta[j], tau.y[j])
##D          theta[j] ~ dnorm (mu.theta, tau.theta)
##D          tau.y[j] <- pow(sigma.y[j], -2)
##D        }
##D        mu.theta ~ dnorm (0.0, 1.0E-6)
##D        tau.theta <- pow(sigma.theta, -2)
##D        sigma.theta ~ dunif (0, 1000)
##D      }  
##D inits <- function(){
##D     list(theta=rnorm(nrow(schools), 0, 100), mu.theta=rnorm(1, 0, 100),
##D          sigma.theta=runif(1, 0, 100))
##D }
##D param <- c("mu.theta", "sigma.theta")
##D sim <- bugs.fit(dat, param, bugs.model, inits)
##D dat2 <- dclone(dat, 2, multiply="J")
##D sim2 <- bugs.fit(dat2, param, bugs.model)
##D #### fitting the model with OpenBUGS
##D sim3 <- bugs.fit(dat2, param, bugs.model, program="openbugs", n.thin=1)
##D #### fitting the model with JAGS
##D sim4 <- jags.fit(dat2, param, bugs.model)
## End(Not run)



